@@ -177,7 +177,7 @@ def store(request, project=None):
 
             insert_data_to_database(data)
         except APIError, error:
-            logger.error('Client %r raised API error: %s', client, error, extra={
+            logger.info('Client %r raised API error: %s', client, error, extra={
                 'request': request,
             }, exc_info=True)
             response = HttpResponse(unicode(error.msg), status=error.http_status)
